@@ -30,7 +30,7 @@ def get_inject_params(func, data):
         else:
             value = data.get(name, parameter.default)
         if not parameter.annotation is parameter.empty:
-            value = typingutils.smart_cast(parameter.annotation, value)
+            value = typingutils.smart_cast(parameter.annotation, value, field_name=name)
         params[name] = value
     return params
 
