@@ -127,6 +127,7 @@ def get_simple_config(logfile:str=None, loglevel:str=None, logfmt:str=None, logg
     Use logging parameter to override the whole settings.
 
     """
+    loggers = loggers or {}
     config = logging or {}
     logfile = logfile or config.get("logfile", "app.log")
     loglevel = loglevel or config.get("loglevel", "INFO")
@@ -135,7 +136,7 @@ def get_simple_config(logfile:str=None, loglevel:str=None, logfmt:str=None, logg
     logfolder = os.path.abspath(os.path.dirname(logfile))
     if not os.path.exists(logfolder):
         os.makedirs(logfolder, exist_ok=True)
-
+    # default logging template
     logging_config = {
         "version": 1,
         "disable_existing_loggers": False,
