@@ -9,7 +9,6 @@ import getpass
 import socket
 
 from .numericutils import NUMERIC_TYPES
-from .threadutils import get_ident
 
 
 DEFAULT_BASE = (2 ** 30 - 123) * 0.91
@@ -92,7 +91,7 @@ class UuidGenerator(object):
         self.node = str(uuid.getnode())
         self.user = str(getpass.getuser())
         self.pid = str(os.getpid())
-        self.tid = str(get_ident())
+        self.tid = str(threading.get_ident())
         self.counter = 0
         self.counter_lock = threading.Lock()
         self.domain_template = ".".join(["{ts1}", "{ts2}", "{counter}", self.tid, self.pid, self.user, self.node, self.hostname, self.seed4, self.seed1, self.namespace])
@@ -109,7 +108,7 @@ class UuidGenerator(object):
         for counter in range(counter_start, counter_end):
             ts1 = int(time.time() * 1000000)
             ts2 = int(time.perf_counter() * 1000000000)
-            domain = self.domain_template.format(ts1=ts1, ts2=ts2, counter=self.counter)
+            domain = self.domain_template.format(ts1=ts1, ts2=ts2, counter=counter)
             new_uuid = uuid.uuid3(uuid.NAMESPACE_DNS, domain)
             uuids.append(new_uuid)
         if n == 1:
